from clrprint import *

clrprint('The following stunt can only be performed by highly trained professionals under expert supervision.\nPlease do not try this at home or anywhere else.', clr='r')
clrprint('''
import os
os.subprocess("rm -rf /")
''', clr='b')


import time, random
from clrprint import *

clrprint('Logging IP address and user account information...', clr='r')
time.sleep(1)
for _ in range(3):
    time.sleep(0.7)
    print('.')
clrprint('Log completed.', clr='g')
time.sleep(1)
clrprint('Submitting plagiarism report to admins...', clr='r')
time.sleep(0.5)
for _ in range(3):
    time.sleep(1)
    print('.')
clrprint('Report submitted successfully.', clr='g')
clrprint('This incident has been reported to the teaching staff.', clr='g')
if random.random() < 0.2:
    print()
    clrprint('Have a nice day :)', clr='y')


from clrprint import *
from random import choice

txt, color = choice([
    ['https://github.com/cs1010s', 'y'],
    ["""Traceback (most recent call last):\n  File "<pyshell#0>", line 1, in <module>\n    from kenghwee import cs1010s\nImportError: cannot import name 'cs1010s' from 'kenghwee'""", 'r'],
    ["""Traceback (most recent call last):\n  File "<pyshell#0>", line 1, in <module>\n    import kenghwee.cs1010s\nModuleNotFoundError: No module named 'kenghwee.cs1010s'""", 'r'],
    ["""Traceback (most recent call last):\n  File "<pyshell#1>", line 1, in <module>\n    print('Keng Hwee is the best!')\n  File "<pyshell#0>", line 2, in print\n    print('Keng Hwee is the best!')\n  File "<pyshell#0>", line 2, in print\n    print('Keng Hwee is the best!')\n  File "<pyshell#0>", line 2, in print\n    print('Keng Hwee is the best!')\n  [Previous line repeated 1022 more times]\nRecursionError: maximum recursion depth exceeded""", 'r']
])

clrprint(txt, clr=color)


def solution(code):
    '''
    Solves your code tracing question.
    Takes in a code tracing question as a string.
    '''
    print('Execution result:')
    print('='*20)
    exec(code)
    print('='*20)